@@ -81,6 +81,8 @@ gnome_vfs_file_info_fields_get_type (void)
       { GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE, "GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE", "mime-type" },
       { GNOME_VFS_FILE_INFO_FIELDS_ACCESS, "GNOME_VFS_FILE_INFO_FIELDS_ACCESS", "access" },
       { GNOME_VFS_FILE_INFO_FIELDS_IDS, "GNOME_VFS_FILE_INFO_FIELDS_IDS", "ids" },
+      { GNOME_VFS_FILE_INFO_FIELDS_ACL, "GNOME_VFS_FILE_INFO_FIELDS_ACL", "acl" },
+      { GNOME_VFS_FILE_INFO_FIELDS_SELINUX_CONTEXT, "GNOME_VFS_FILE_INFO_FIELDS_SELINUX_CONTEXT", "selinux-context" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("GnomeVFSFileInfoFields", values);
@@ -129,6 +131,9 @@ gnome_vfs_file_info_options_get_type (void)
       { GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE, "GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE", "force-slow-mime-type" },
       { GNOME_VFS_FILE_INFO_FOLLOW_LINKS, "GNOME_VFS_FILE_INFO_FOLLOW_LINKS", "follow-links" },
       { GNOME_VFS_FILE_INFO_GET_ACCESS_RIGHTS, "GNOME_VFS_FILE_INFO_GET_ACCESS_RIGHTS", "get-access-rights" },
+      { GNOME_VFS_FILE_INFO_NAME_ONLY, "GNOME_VFS_FILE_INFO_NAME_ONLY", "name-only" },
+      { GNOME_VFS_FILE_INFO_GET_ACL, "GNOME_VFS_FILE_INFO_GET_ACL", "get-acl" },
+      { GNOME_VFS_FILE_INFO_GET_SELINUX_CONTEXT, "GNOME_VFS_FILE_INFO_GET_SELINUX_CONTEXT", "get-selinux-context" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("GnomeVFSFileInfoOptions", values);
@@ -146,6 +151,8 @@ gnome_vfs_set_file_info_mask_get_type (void)
       { GNOME_VFS_SET_FILE_INFO_PERMISSIONS, "GNOME_VFS_SET_FILE_INFO_PERMISSIONS", "permissions" },
       { GNOME_VFS_SET_FILE_INFO_OWNER, "GNOME_VFS_SET_FILE_INFO_OWNER", "owner" },
       { GNOME_VFS_SET_FILE_INFO_TIME, "GNOME_VFS_SET_FILE_INFO_TIME", "time" },
+      { GNOME_VFS_SET_FILE_INFO_ACL, "GNOME_VFS_SET_FILE_INFO_ACL", "acl" },
+      { GNOME_VFS_SET_FILE_INFO_SELINUX_CONTEXT, "GNOME_VFS_SET_FILE_INFO_SELINUX_CONTEXT", "selinux-context" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("GnomeVFSSetFileInfoMask", values);
