@@ -130,7 +130,7 @@ typedef struct {
 } HalIconPair;
 
 /* by design, the enums are laid out so we can do easy computations */
-static HalIconPair hal_icon_mapping[] = {
+static const HalIconPair hal_icon_mapping[] = {
 	{HAL_ICON_DRIVE_REMOVABLE_DISK,           "gnome-dev-removable"},
 	{HAL_ICON_DRIVE_REMOVABLE_DISK_IDE,       "gnome-dev-removable"},
 	{HAL_ICON_DRIVE_REMOVABLE_DISK_SCSI,      "gnome-dev-removable"},
@@ -618,8 +618,10 @@ static gboolean
 _hal_volume_policy_check (GnomeVFSVolumeMonitorDaemon *volume_monitor_daemon, 
 			  LibHalDrive *hal_drive, LibHalVolume *hal_volume)
 {
+#if 0
 	const char *label;
 	const char *fstype;
+#endif
 	gboolean ret;
 	const char *fhs23_toplevel_mount_points[] = {
 		"/",
@@ -692,16 +694,14 @@ _hal_volume_policy_check (GnomeVFSVolumeMonitorDaemon *volume_monitor_daemon,
 			}
 		}
 	}
-
+#if 0
 	label = libhal_volume_get_label (hal_volume);
 	fstype = libhal_volume_get_fstype (hal_volume);
 
 	/* blacklist partitions with name 'bootstrap' of type HFS (Apple uses that) */
-/*
 	if (label != NULL && fstype != NULL && strcmp (label, "bootstrap") == 0 && strcmp (fstype, "hfs") == 0)
 		goto out;
-*/
-
+#endif
 	ret = TRUE;
 out:
 	return ret;
@@ -791,7 +791,6 @@ _hal_add_drive_without_volumes (GnomeVFSVolumeMonitorDaemon *volume_monitor_daem
 {
 	GnomeVFSDrive *drive;
 	GnomeVFSVolumeMonitor *volume_monitor;
-	GnomeVFSHalUserData *hal_userdata;
 	char *name;
 	DBusError error;
 	gboolean media_check_enabled;
@@ -804,7 +803,6 @@ _hal_add_drive_without_volumes (GnomeVFSVolumeMonitorDaemon *volume_monitor_daem
 #endif
 
 	volume_monitor = GNOME_VFS_VOLUME_MONITOR (volume_monitor_daemon);
-	hal_userdata = (GnomeVFSHalUserData *) libhal_ctx_get_user_data (volume_monitor_daemon->hal_ctx);
 
 	if (!_hal_drive_policy_check (volume_monitor_daemon, hal_drive, NULL)) {
 		/* make sure to delete the drive/volume for policy changes */
@@ -830,7 +828,7 @@ _hal_add_drive_without_volumes (GnomeVFSVolumeMonitorDaemon *volume_monitor_daem
 		goto out;
 	}
 	
-	dbus_error_init (&error);
+ 	dbus_error_init (&error);
  	media_check_enabled = libhal_device_get_property_bool (volume_monitor_daemon->hal_ctx,
  							       libhal_drive_get_udi (hal_drive),
  							       "storage.media_check_enabled",
@@ -851,10 +849,10 @@ _hal_add_drive_without_volumes (GnomeVFSVolumeMonitorDaemon *volume_monitor_daem
 	name = _hal_drive_policy_get_display_name (volume_monitor_daemon, hal_drive, NULL);
 	drive->priv->display_name = _gnome_vfs_volume_monitor_uniquify_drive_name (volume_monitor, name);
 	g_free (name);
+	drive->priv->is_user_visible = !media_check_enabled; /* See http://bugzilla.gnome.org/show_bug.cgi?id=321320 */
 	name = g_utf8_casefold (drive->priv->display_name, -1);
 	drive->priv->display_name_key = g_utf8_collate_key (name, -1);
 	g_free (name);
-	drive->priv->is_user_visible = !media_check_enabled; /* See http://bugzilla.gnome.org/show_bug.cgi?id=321320 */
 	drive->priv->volumes = NULL;
 	drive->priv->hal_udi = g_strdup (libhal_drive_get_udi (hal_drive));
         drive->priv->must_eject_at_unmount = libhal_drive_requires_eject (hal_drive);
@@ -878,7 +876,6 @@ _hal_add_volume (GnomeVFSVolumeMonitorDaemon *volume_monitor_daemon,
 	GnomeVFSVolume *vol;
 	GnomeVFSDrive *drive;
 	GnomeVFSVolumeMonitor *volume_monitor;
-	GnomeVFSHalUserData *hal_userdata;
 	char *name;
 	gboolean allowed_by_policy;
 	const char *backing_udi;
@@ -890,7 +887,6 @@ _hal_add_volume (GnomeVFSVolumeMonitorDaemon *volume_monitor_daemon,
 	backing_udi = NULL;
 
 	volume_monitor = GNOME_VFS_VOLUME_MONITOR (volume_monitor_daemon);
-	hal_userdata = (GnomeVFSHalUserData *) libhal_ctx_get_user_data (volume_monitor_daemon->hal_ctx);
 
 	allowed_by_policy = _hal_volume_policy_check (volume_monitor_daemon, hal_drive, hal_volume);
 
@@ -1496,9 +1492,6 @@ void
 _gnome_vfs_hal_mounts_shutdown (GnomeVFSVolumeMonitorDaemon *volume_monitor_daemon)
 {
 	DBusError error;
-	GnomeVFSHalUserData *hal_userdata;
-
-	hal_userdata = (GnomeVFSHalUserData *) libhal_ctx_get_user_data (volume_monitor_daemon->hal_ctx);
 
 	dbus_error_init (&error);
 	if (!libhal_ctx_shutdown (volume_monitor_daemon->hal_ctx, &error)) {
