@@ -31,15 +31,14 @@ System (version for POSIX threads).
 #include "gnome-vfs-job.h"
 
 #include "gnome-vfs-async-job-map.h"
-#include "gnome-vfs-job-slave.h"
 #include "gnome-vfs-job-queue.h"
 #include "gnome-vfs-private-utils.h"
 #include <errno.h>
 #include <glib/gmessages.h>
 #include <glib/gstrfuncs.h>
+#include <glib/gi18n-lib.h>
 #include <libgnomevfs/gnome-vfs-cancellable-ops.h>
 #include <libgnomevfs/gnome-vfs-context.h>
-#include <libgnomevfs/gnome-vfs-i18n.h>
 #include <libgnomevfs/gnome-vfs-backend.h>
 #include <string.h>
 #include <unistd.h>
@@ -48,7 +47,7 @@ static GStaticPrivate job_private = G_STATIC_PRIVATE_INIT;
 
 #if GNOME_VFS_JOB_DEBUG
 
-char *job_debug_types[] = {
+static const char *job_debug_types[] = {
 	"open", "open as channel",
 	"create", "create symbolic link",
 	"create as channel", "close",
@@ -731,7 +730,7 @@ gnome_vfs_op_destroy (GnomeVFSOp *op)
 		g_free (op->specifics.file_control.operation);
 		break;
 	default:
-		g_warning (_("Unknown op type %u"), op->type);
+		g_warning (_("Unknown operation type %u"), op->type);
 	}
 	
 	g_assert (gnome_vfs_context_get_cancellation (op->context) != NULL);
@@ -847,7 +846,7 @@ serve_channel_read (GnomeVFSHandle *handle,
 
 					fd = g_io_channel_unix_get_fd (channel_out);
 					
-					_gnome_vfs_clear_fd_flags (fd, O_NONBLOCK);
+					_gnome_vfs_pipe_set_blocking (fd, TRUE);
 				} else {
 					if (written_bytes_in_buffer > 0) {
 						/* Need to shift the unwritten bytes
@@ -913,7 +912,7 @@ serve_channel_write (GnomeVFSHandle *handle,
 
 		io_result = g_io_channel_read_chars (channel_in, buffer, buffer_size,
 						     &bytes_read, NULL);
-
+                
 		if (io_result == G_IO_STATUS_AGAIN)
 			continue;
 		if (io_result != G_IO_STATUS_NORMAL || bytes_read == 0)
@@ -1019,8 +1018,9 @@ execute_open_as_channel (GnomeVFSJob *job)
 		job_oneway_notify (job, notify_result);
 		return;
 	}
+	
 
-	if (pipe (pipefd) < 0) {
+	if (_gnome_vfs_pipe (pipefd) < 0) {
 		g_warning (_("Cannot create pipe for open GIOChannel: %s"),
 			   g_strerror (errno));
 		notify_result->specifics.open_as_channel.result = GNOME_VFS_ERROR_INTERNAL;
@@ -1034,11 +1034,15 @@ execute_open_as_channel (GnomeVFSJob *job)
 	 * thread is blocking for some reason the slave can keep
 	 * reading data.
 	 */
-	_gnome_vfs_set_fd_flags (pipefd[1], O_NONBLOCK);
+	_gnome_vfs_pipe_set_blocking (pipefd[1], FALSE);
 	
+#ifndef G_OS_WIN32
 	channel_in = g_io_channel_unix_new (pipefd[0]);
 	channel_out = g_io_channel_unix_new (pipefd[1]);
-
+#else
+	channel_in = g_io_channel_win32_new_socket (pipefd[0]);
+	channel_out = g_io_channel_win32_new_socket (pipefd[1]);
+#endif
 	open_mode = open_as_channel_op->open_mode;
 	
 	if (open_mode & GNOME_VFS_OPEN_READ) {
@@ -1144,10 +1148,12 @@ execute_create_as_channel (GnomeVFSJob *job)
 	if (create_as_channel_op->uri == NULL) {
 		result = GNOME_VFS_ERROR_INVALID_URI;
 	} else {
-		result = gnome_vfs_open_uri_cancellable
+		result = gnome_vfs_create_uri_cancellable
 			(&handle,
 			 create_as_channel_op->uri,
 			 create_as_channel_op->open_mode,
+                         create_as_channel_op->exclusive,
+                         create_as_channel_op->perm,
 			 job->op->context);
 	}
 	
@@ -1165,7 +1171,7 @@ execute_create_as_channel (GnomeVFSJob *job)
 		return;
 	}
 
-	if (pipe (pipefd) < 0) {
+	if (_gnome_vfs_pipe (pipefd) < 0) {
 		g_warning (_("Cannot create pipe for open GIOChannel: %s"),
 			   g_strerror (errno));
 		notify_result->specifics.create_as_channel.result = GNOME_VFS_ERROR_INTERNAL;
@@ -1175,8 +1181,13 @@ execute_create_as_channel (GnomeVFSJob *job)
 		return;
 	}
 	
+#ifndef G_OS_WIN32
 	channel_in = g_io_channel_unix_new (pipefd[0]);
 	channel_out = g_io_channel_unix_new (pipefd[1]);
+#else
+	channel_in = g_io_channel_win32_new_socket (pipefd[0]);
+	channel_out = g_io_channel_win32_new_socket (pipefd[1]);
+#endif
 
 	notify_result->specifics.create_as_channel.channel = channel_out;
 
@@ -1188,11 +1199,8 @@ execute_create_as_channel (GnomeVFSJob *job)
 static void
 execute_close (GnomeVFSJob *job)
 {
-	GnomeVFSCloseOp *close_op;
 	GnomeVFSNotifyResult *notify_result;
 
-	close_op = &job->op->specifics.close;
-
 	notify_result = g_new0 (GnomeVFSNotifyResult, 1);
 	notify_result->job_handle = job->job_handle;
 	notify_result->type = job->op->type;
@@ -1508,10 +1516,6 @@ load_directory_details (GnomeVFSJob *job)
 static void
 execute_load_directory (GnomeVFSJob *job)
 {
-	GnomeVFSLoadDirectoryOp *load_directory_op;
-
-	load_directory_op = &job->op->specifics.load_directory;
-
 	load_directory_details (job);
 }
 
