@@ -25,6 +25,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <assert.h>
 #include "xdgmimemagic.h"
 #include "xdgmimeint.h"
@@ -43,8 +47,6 @@
 #define	TRUE	(!FALSE)
 #endif
 
-extern int errno;
-
 typedef struct XdgMimeMagicMatch XdgMimeMagicMatch;
 typedef struct XdgMimeMagicMatchlet XdgMimeMagicMatchlet;
 
@@ -264,7 +266,7 @@ _xdg_mime_magic_parse_header (FILE *magic_file, XdgMimeMagicMatch *match)
   if (c != ':')
     return XDG_MIME_MAGIC_ERROR;
 
-  buffer = _xdg_mime_magic_read_to_newline (magic_file, &end_of_file);
+  buffer = (char *)_xdg_mime_magic_read_to_newline (magic_file, &end_of_file);
   if (end_of_file)
     return XDG_MIME_MAGIC_EOF;
 
@@ -516,8 +518,7 @@ _xdg_mime_magic_matchlet_compare_to_data (XdgMimeMagicMatchlet *matchlet,
 					  size_t                len)
 {
   int i, j;
-
-  for (i = matchlet->offset; i <= matchlet->offset + matchlet->range_length; i++)
+  for (i = matchlet->offset; i < matchlet->offset + matchlet->range_length; i++)
     {
       int valid_matchlet = TRUE;
 
@@ -635,8 +636,10 @@ _xdg_mime_magic_new (void)
 void
 _xdg_mime_magic_free (XdgMimeMagic *mime_magic)
 {
-  if (mime_magic)
+  if (mime_magic) {
+    _xdg_mime_magic_match_free (mime_magic->match_list);
     free (mime_magic);
+  }
 }
 
 int
@@ -648,19 +651,57 @@ _xdg_mime_magic_get_buffer_extents (XdgMimeMagic *mime_magic)
 const char *
 _xdg_mime_magic_lookup_data (XdgMimeMagic *mime_magic,
 			     const void   *data,
-			     size_t        len)
+			     size_t        len,
+                             const char   *mime_types[],
+                             int           n_mime_types)
 {
   XdgMimeMagicMatch *match;
+  const char *mime_type;
+  int n;
+  int priority;
+  int had_match;
 
+  mime_type = NULL;
+  priority = 0;
+  had_match = 0;
   for (match = mime_magic->match_list; match; match = match->next)
     {
       if (_xdg_mime_magic_match_compare_to_data (match, data, len))
 	{
-	  return match->mime_type;
+	  if (!had_match || match->priority > priority ||
+	      (mime_type != NULL && xdg_mime_mime_type_subclass (match->mime_type, mime_type)))
+	    {
+	      mime_type = match->mime_type;
+	      priority = match->priority;
+	    }
+	  else if (had_match && match->priority == priority)
+	    /* multiple unrelated patterns with the same priority matched,
+	     * so we can't tell what type this is. */
+	    mime_type = NULL;
+
+	  had_match = 1;
+	}
+      else 
+	{
+	  for (n = 0; n < n_mime_types; n++)
+	    {
+	      if (mime_types[n] && 
+		  xdg_mime_mime_type_equal (mime_types[n], match->mime_type))
+		mime_types[n] = NULL;
+	    }
 	}
     }
 
-  return NULL;
+  if (mime_type == NULL)
+    {
+      for (n = 0; n < n_mime_types; n++)
+	{
+	  if (mime_types[n])
+	    mime_type = mime_types[n];
+	}
+    }
+
+  return mime_type;
 }
 
 static void
@@ -765,9 +806,11 @@ _xdg_mime_magic_read_from_file (XdgMimeMagic *mime_magic,
   if (magic_file == NULL)
     return;
 
-  fread (header, 1, 12, magic_file);
+  if (fread (header, 1, 12, magic_file) == 12)
+    {
+      if (memcmp ("MIME-Magic\0\n", header, 12) == 0)
+        _xdg_mime_magic_read_magic_file (mime_magic, magic_file);
+    }
 
-  if (memcmp ("MIME-Magic\0\n", header, 12) == 0)
-    _xdg_mime_magic_read_magic_file (mime_magic, magic_file);
   fclose (magic_file);
 }
